Index: src/crankshaft/x87/lithium-codegen-x87.cc |
diff --git a/src/crankshaft/x87/lithium-codegen-x87.cc b/src/crankshaft/x87/lithium-codegen-x87.cc |
index 985734ce10af624a9ab38b7ffc8a75284ebe3a78..b83d97f981b984321f8be185bbb1fdf20c9acae4 100644 |
--- a/src/crankshaft/x87/lithium-codegen-x87.cc |
+++ b/src/crankshaft/x87/lithium-codegen-x87.cc |
@@ -2900,11 +2900,11 @@ void LCodeGen::DoLoadKeyedFixedArray(LLoadKeyed* instr) { |
__ j(not_equal, &done); |
if (info()->IsStub()) { |
// A stub can safely convert the hole to undefined only if the array |
// protector cell contains (Smi) Isolate::kArrayProtectorValid. |
// Otherwise it needs to bail out. |
__ LoadRoot(result, Heap::kArrayProtectorRootIndex); |
__ cmp(FieldOperand(result, PropertyCell::kValueOffset), |
- Immediate(Smi::FromInt(Isolate::kArrayProtectorValid))); |
+ Immediate(Smi::FromInt(Isolate::kProtectorValid))); |
DeoptimizeIf(not_equal, instr, DeoptimizeReason::kHole); |
} |
__ mov(result, isolate()->factory()->undefined_value()); |
@@ -2900,11 +2900,11 @@ void LCodeGen::DoLoadKeyedFixedArray(LLoadKeyed* instr) { |
if (info()->IsStub()) { |
// A stub can safely convert the hole to undefined only if the array |
- // protector cell contains (Smi) Isolate::kArrayProtectorValid. |
+ // protector cell contains (Smi) Isolate::kProtectorValid. |
// Otherwise it needs to bail out. |
__ LoadRoot(result, Heap::kArrayProtectorRootIndex); |